#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 weigh
version:              0.0.18
visibility:           public
id:                   weigh-0.0.18-3AywfLUnAss2WigllSoh3s
key:                  weigh-0.0.18-3AywfLUnAss2WigllSoh3s
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  42223cfb0a1a8fb6d4dbcd6025e0c348
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.18-3AywfLUnAss2WigllSoh3s
depends:
    base-4.18.2.1 criterion-measurement-0.2.4.0-L7S0YF4zB8Z5B5jgKTy8Yw
    deepseq-1.4.8.1 mtl-2.3.1 process-1.6.19.0
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    temporary-1.3-6jR9Y0qK20e3lOLKCzgpYi

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

